pub struct CollectionDetailsResponseModel {
pub object: Option<String>,
pub id: Option<Uuid>,
pub organization_id: Option<Uuid>,
pub name: Option<String>,
pub external_id: Option<String>,
pub type: Option<CollectionType>,
pub default_user_collection_email: Option<String>,
pub read_only: Option<bool>,
pub hide_passwords: Option<bool>,
pub manage: Option<bool>,
pub has_enabled_access_rule: Option<bool>,
}Expand description
CollectionDetailsResponseModel : Response model for a collection that is always assigned to the requesting user, including permissions.
Fields
object: Option<String>id: Option<Uuid>organization_id: Option<Uuid>name: Option<String>external_id: Option<String>type: Option<CollectionType>default_user_collection_email: Option<String>read_only: Option<bool>hide_passwords: Option<bool>manage: Option<bool>has_enabled_access_rule: Option<bool>True if the collection is governed by an access rule that is currently enabled. Lets a client mark the collection as privileged without reading the organization’s access rules.
Implementations
Sourceimpl CollectionDetailsResponseModel
impl CollectionDetailsResponseModel
Sourcepub fn new() -> CollectionDetailsResponseModel
pub fn new() -> CollectionDetailsResponseModel
Response model for a collection that is always assigned to the requesting user, including permissions.